@@ -8,7 +8,11 @@ from adlinear import nmfmodel as nmf
 from randomgenerators import randomgenerators as rng
 import dotenv
 
-Path.set_global_fs("gcs", bucket="nmf_experiments_dev", token="cred_gcs.json")
+local_main_coon = True
+if local_main_coon:
+    Path.set_global_fs("local")
+else:
+    Path.set_global_fs("gcs", bucket="nmf_experiments_dev", token="cred_gcs.json")
 dotenv.load_dotenv()
 
 if __name__ == "__main__":
@@ -24,8 +28,8 @@ if __name__ == "__main__":
     parser.add_argument("-e", "--epsilon", type=float, default=0.10, help="Epsilon")
     parser.add_argument("-m", "--ncmin", type=int, default=2, help="Minimum number of components")
     parser.add_argument("-M", "--ncmax", type=int, default=45, help="Maximum number of components")
-    parser.add_argument("-W", "--w_avg", type=int, default=2, help="Average size of W clusters")
-    parser.add_argument("-H", "--h_avg", type=int, default=10, help="Average size of H clusters")
+    parser.add_argument("-W", "--w_ncr", type=int, default=0, help="Ratio of #W-clusters to #components")
+    parser.add_argument("-H", "--h_ncr", type=int, default=1, help="Ratio of #H-clusters to #components")
     # parser.add_argument("-a", "--wclust_f", type=float, default=1.0, help="#W clusters to #H clusters maximum ratio")
     parser.add_argument("-i", "--icorrmin", type=float, default=0.5, help="Minimum intra-cluster correlation")
     parser.add_argument("-I", "--icorrmax", type=float, default=0.95, help="Maximum intra-cluster correlation")
@@ -39,8 +43,8 @@ if __name__ == "__main__":
     ncmax = args.ncmax
     nruns = args.runs
     # wclust_f = args.wclust_f
-    w_avg = args.w_avg
-    h_avg = args.h_avg
+    w_ncr = args.w_ncr
+    h_ncr = args.h_ncr
     do_ent = args.do_entropy
     icorrmin = args.icorrmin
     icorrmax = args.icorrmax
@@ -53,38 +57,32 @@ if __name__ == "__main__":
     rand_norms = True
     df_mini_scree_plots = pd.DataFrame(index=[], columns=[])
     for itrial in range(nruns):
-        nb_clusters = np.random.randint(low=ncmin, high=ncmax)
-        intra_corr = np.random.uniform(low=icorrmin, high=icorrmax)
-        xtra_corr = np.random.uniform(low=xcorrmin, high=xcorrmax)
-        h_size = h_avg * nb_clusters
-        # w_size = np.random.randint(low=max(nb_clusters, int(h_size / 5.0)), high=5*h_size)
-        w_size = np.random.randint(low=max(nb_clusters, int(h_size / 5.0)), high=5 * h_size)
-        eps = np.random.uniform(low=0.0, high=epsilon)
-        # TODO: lift the constraint that W and H have same number of clusters
-        # w_avg = h_avg
-        # nb_w_clusters = max(int(w_size / w_avg), 1)
-        nb_w_clusters = nb_clusters
-        w_avg = int(w_size / nb_w_clusters)
-        # wclust_factor = np.random.uniform(0.0, wclust_f)
+        n_comp = np.random.randint(low=ncmin, high=ncmax)
+        # intra_corr = np.random.uniform(low=icorrmin, high=icorrmax)
+        # xtra_corr = np.random.uniform(low=xcorrmin, high=xcorrmax)
+        h_size = np.random.randint(low=max(n_comp, 10), high=1000)
+        w_size = np.random.randint(low=max(n_comp, int(h_size / 5.0)), high=5 * h_size)
+        h_nc = int(h_ncr * n_comp)
+        w_nc = int(w_ncr * n_comp)
 
+        eps = np.random.uniform(low=0.0, high=epsilon)
         # noinspection PyTupleAssignmentBalance
-        generated_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
+        generated_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=n_comp, n_feat=h_size, n_obs=w_size,
                                                                h_icorr_min=icorrmin, h_xcorr_max=xcorrmax,
                                                                w_icorr_min=xcorrmin, w_xcorr_max=icorrmax,
-                                                               random_norms=rand_norms, epsilon=eps, avg_w_clust=w_avg,
-                                                               avg_h_clust=h_avg)
+                                                               random_norms=rand_norms, epsilon=eps, n_clust_w=w_nc,
+                                                               n_clust_h=h_nc)
         rnstr = "RandNorms" if rand_norms else "ConstNorms"
 
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax, known_ncomp=nb_clusters,
-                                                do_entropies=do_ent)
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax, known_ncomp=n_comp,
+                                                do_entropies=do_ent, do_stabilities=False)
         df_mini_scree_plots = nmf.collect_windows_from_scree_plot(df_collected_windows=df_mini_scree_plots,
-                                                                  df_scree_plot=df_scree_plot, known_ncomp=nb_clusters,
+                                                                  df_scree_plot=df_scree_plot, known_ncomp=n_comp,
                                                                   ncomp_margin=5)
 
         if itrial % writefreq == 0 or itrial == nruns-1:
             print(f"Saving iteration {itrial} in {outputpath}")
             # assert not df_mini_scree_plots.empty
             outputpath.write(df_mini_scree_plots)
-            # df_scree_plot.to_csv(args.output.split(".csv")[0]+f"_scp{itrial}_nc{nb_clusters}.csv")
             assert outputpath.isfile()
             assert not outputpath.read().empty
