@@ -319,7 +319,7 @@ if __name__ == "__main__":
                                                                          n_obs=w_size, h_icorr_min=min_corr,
                                                                          h_xcorr_max=max_corr,
                                                                          random_norms=random_norms, epsilon=eps,
-                                                                         avg_w_clust=wclust_factor)
+                                                                         n_clust_w=wclust_factor)
         for censor_indices in censor_indices_list:
 
             utl.censor_data(mat=gen_m, censored_indices=censor_indices, inplace=True)
